@@ -110,11 +110,15 @@ class MetaData(dict):
         (defaults to :const:`afmformats.meta.KEYS_VALID`).
 
         The "time" key is converted using :func:`parse_time`.
+        NaN values are silently ignored.
         """
         if key not in self.valid_keys:
             raise KeyError("Unknown metadata key: '{}'".format(key))
         elif key == "time":
             value = parse_time(value)
+        if isinstance(value, np.float) and np.isnan(value):
+            # nan values are ignored
+            return
         super(MetaData, self).__setitem__(key, value)
 
     def __getitem__(self, key):
@@ -123,7 +127,7 @@ class MetaData(dict):
         elif key == "session id":
             return self._get_session_id()
         elif key not in self and key in self.valid_keys:
-            msg = "No meta data was defined for '{}'!".format(key) \
+            msg = "No meta data was defined for '{}'! ".format(key) \
                   + "Please make sure you passed the dictionary `metadata` " \
                   + "when you loaded your data."
             raise MetaDataMissingError(msg)
